==> guikachu-1.1.3.tar.gz: guikachu-1.1.3/src/form-editor/selector-trigger-prop.cc <==
//$Id: selector-trigger-prop.cc,v 1.8 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "selector-trigger-prop.h"

#include "config.h"
#include <libgnome/libgnome.h>

#include "widget-prop.h"
#include "resizeable-prop.h"
#include "textual-prop.h"

#include "widgets/entry.h"
#include "widgets/num-entry.h"
#include "widgets/togglebutton.h"
#include "widgets/propertytable.h"

using namespace Guikachu::GUI::FormEditor;
using namespace Guikachu::Widgets;

SelectorTriggerProperties::SelectorTriggerProperties (SelectorTrigger *res)
{
    using namespace Gtk;
    using namespace SigC;

    GUI::PropertyTable *proptable = new GUI::PropertyTable ();
    Gtk::Widget *control;
    
    /* Resource ID */
    WidgetProperties::add_general_controls (res, *proptable);

    /* Label */
    TextualProperties::add_controls (res, *proptable);

    /* Usable */
    control = new GUI::PropertyEditors::ToggleButton (res->usable);
    proptable->add (_("_Usable:"), *manage (control),
		    _("Non-usable widgets are not rendered by default"));

    /* Anchor right */
    control = new GUI::PropertyEditors::ToggleButton (res->anchor_right);
    proptable->add (_("A_nchor right:"), *manage (control),
		    _("Keep right aligned when changing label "
		      "text at run-time"));
    
    /* Separator */
    proptable->add_separator ();

    /* Position */
    WidgetProperties::add_position_controls (res, *proptable);
    
    /* Size */
    ResizeableProperties::add_controls (res, *proptable);
    
    proptable->show ();
    property_editor = proptable;
}

SelectorTriggerProperties::~SelectorTriggerProperties ()
{
    delete property_editor;
}

Gtk::Widget* SelectorTriggerProperties::get_editor ()
{
    return property_editor;
}

==> guikachu-1.3.1.tar.gz: guikachu-1.3.1/src/form-editor/selector-trigger-prop.cc <==
//$Id: selector-trigger-prop.cc,v 1.9 2002/01/26 00:19:17 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "selector-trigger-prop.h"

#include "config.h"
#include <libgnome/libgnome.h>

#include "widget-prop.h"
#include "auto-resizeable-prop.h"
#include "textual-prop.h"

#include "widgets/entry.h"
#include "widgets/num-entry.h"
#include "widgets/togglebutton.h"
#include "widgets/propertytable.h"

using namespace Guikachu::GUI::FormEditor;
using namespace Guikachu::Widgets;

SelectorTriggerProperties::SelectorTriggerProperties (SelectorTrigger *res)
{
    using namespace Gtk;
    using namespace SigC;

    GUI::PropertyTable *proptable = new GUI::PropertyTable ();
    Gtk::Widget *control;
    
    /* Resource ID */
    WidgetProperties::add_general_controls (res, *proptable);

    /* Label */
    TextualProperties::add_controls (res, *proptable);

    /* Usable */
    control = new GUI::PropertyEditors::ToggleButton (res->usable);
    proptable->add (_("_Usable:"), *manage (control),
		    _("Non-usable widgets are not rendered by default"));

    /* Anchor right */
    control = new GUI::PropertyEditors::ToggleButton (res->anchor_right);
    proptable->add (_("A_nchor right:"), *manage (control),
		    _("Keep right aligned when changing label "
		      "text at run-time"));
    
    /* Separator */
    proptable->add_separator ();

    /* Position */
    WidgetProperties::add_position_controls (res, *proptable);
    
    /* Size */
    AutoWidthProperties::add_controls  (res, *proptable);
    AutoHeightProperties::add_controls (res, *proptable);
    
    proptable->show ();
    property_editor = proptable;
}

SelectorTriggerProperties::~SelectorTriggerProperties ()
{
    delete property_editor;
}

Gtk::Widget* SelectorTriggerProperties::get_editor ()
{
    return property_editor;
}
